# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.tasks_v1_api import TasksV1Api


class TestTasksV1Api(unittest.TestCase):
    """TasksV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = TasksV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_connection_info(self) -> None:
        """Test case for delete_connection_info

        Delete Connection Info.
        """
        pass

    def test_delete_task(self) -> None:
        """Test case for delete_task

        Delete A Task
        """
        pass

    def test_get_task_connection_info(self) -> None:
        """Test case for get_task_connection_info

        Get Task Connection Info
        """
        pass

    def test_get_task_state_cache(self) -> None:
        """Test case for get_task_state_cache

        Get Cached Task State
        """
        pass

    def test_patch_task(self) -> None:
        """Test case for patch_task

        Update A Task
        """
        pass

    def test_post_regenerate_validation_key(self) -> None:
        """Test case for post_regenerate_validation_key

        Regenerate Task Validation Key
        """
        pass

    def test_project_create_model_link_task(self) -> None:
        """Test case for project_create_model_link_task

        Link An Existing Task To A New Model.
        """
        pass

    def test_project_create_model_task(self) -> None:
        """Test case for project_create_model_task

        Create A Task.
        """
        pass

    def test_put_task_connection_info(self) -> None:
        """Test case for put_task_connection_info

        Upload Task State
        """
        pass

    def test_put_task_state_cache(self) -> None:
        """Test case for put_task_state_cache

        Upload Task State
        """
        pass

    def test_sync_task(self) -> None:
        """Test case for sync_task

        Sync A Task
        """
        pass


if __name__ == '__main__':
    unittest.main()
